summaryrefslogtreecommitdiffstats
path: root/kmail/kmmsgpart.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmsgpart.h')
-rw-r--r--kmail/kmmsgpart.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/kmmsgpart.h b/kmail/kmmsgpart.h
index 000837c7..85906af5 100644
--- a/kmail/kmmsgpart.h
+++ b/kmail/kmmsgpart.h
@@ -58,17 +58,17 @@ public:
**/
void setBodyFromUnicode( const TQString & str );
- /** Returns the body part decoded to unicode.
+ /** Returns the body part decoded to tqunicode.
**/
TQString bodyToUnicode(const TQTextCodec* codec=0) const;
/** Returns body as decoded string. Assumes that content-transfer-encoding
- contains the correct encoding. This routine is meant for binary data.
+ tqcontains the correct encoding. This routine is meant for binary data.
No trailing 0 is appended. */
TQByteArray bodyDecodedBinary(void) const;
/** Returns body as decoded string. Assumes that content-transfer-encoding
- contains the correct encoding. This routine is meant for text strings! */
+ tqcontains the correct encoding. This routine is meant for text strings! */
TQCString bodyDecoded(void) const;
/** Sets body, encoded in the best fitting
@@ -209,7 +209,7 @@ public:
/** Sets the part number */
void setPartSpecifier( const TQString & part ) { mPartSpecifier = part; }
/** If this part is complete (contains a body) */
bool isComplete() { return (!mBody.isNull()); }
/** Returns the parent part */
@@ -209,7 +209,7 @@ public:
/** Sets the part number */
void setPartSpecifier( const TQString & part ) { mPartSpecifier = part; }
- /** If this part is complete (contains a body) */
+ /** If this part is complete (tqcontains a body) */
bool isComplete() { return (!mBody.isNull()); }
/** Returns the parent part */